PyHybridDB Admin Panel

## 🗄️ PyHybridDB

Sign in to access the admin panel

Username
Password

# 🗄️ PyHybridDB Admin Panel

Hybrid Database Management System - SQL & NoSQL in One

Admin
Administrator

## Dashboard

### 0

Databases

### 0

Tables

### 0

Collections

## Databases

Database Name

## Tables

Select Database
Table Name
Schema (JSON format: {"column": "type"})

## Collections

Select Database
Collection Name

## Query Runner

Select Database
Query (SQL or NoSQL)

## Import / Export Data

Select Database

### 📤 Export Data

Export your database data to JSON or CSV format

Export Type
Select Target
Format

### 📥 Import Data

Import data from JSON or CSV files

Import Type
Target Name
Select File